aboutsummaryrefslogtreecommitdiff
path: root/video/video_decoder.h
diff options
context:
space:
mode:
authorMatthew Hoops2012-08-16 13:34:28 -0400
committerMatthew Hoops2012-08-16 13:34:28 -0400
commit7569ec7dc00e95e0643cde7f413a7cf46a4770f0 (patch)
tree7731d640f058b24b42cf6e3b87420d28ca7f0179 /video/video_decoder.h
parentfb35c7f46f986a22235638e2946ba8492e735109 (diff)
downloadscummvm-rg350-7569ec7dc00e95e0643cde7f413a7cf46a4770f0.tar.gz
scummvm-rg350-7569ec7dc00e95e0643cde7f413a7cf46a4770f0.tar.bz2
scummvm-rg350-7569ec7dc00e95e0643cde7f413a7cf46a4770f0.zip
VIDEO: Rename setStopTime() to setEndTime()
To better differentiate with stop()
Diffstat (limited to 'video/video_decoder.h')
-rw-r--r--video/video_decoder.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/video/video_decoder.h b/video/video_decoder.h
index 72be634f17..d6cfcde0b4 100644
--- a/video/video_decoder.h
+++ b/video/video_decoder.h
@@ -360,15 +360,15 @@ public:
void setDefaultHighColorFormat(const Graphics::PixelFormat &format) { _defaultHighColorFormat = format; }
/**
* Set the time for this video to stop at. At this time in the video,
* all audio will stop and endOfVideo() will return true.
*/
- void setStopTime(const Audio::Timestamp &stopTime);
+ void setEndTime(const Audio::Timestamp &endTime);
/**
* Get the stop time of the video (if not set, zero)
*/
- Audio::Timestamp getStopTime() const { return _stopTime; }
+ Audio::Timestamp getEndTime() const { return _endTime; }
// Future API
//void setRate(const Common::Rational &rate);
@@ -761,8 +761,8 @@ private:
// Current playback status
bool _isPlaying, _needsRewind, _needsUpdate;
- Audio::Timestamp _lastTimeChange, _stopTime;
- bool _stopTimeSet;
+ Audio::Timestamp _lastTimeChange, _endTime;
+ bool _endTimeSet;
// Palette settings from individual tracks
mutable bool _dirtyPalette;
@@ -360,15 +360,15 @@ public:
void setDefaultHighColorFormat(const Graphics::PixelFormat &format) { _defaultHighColorFormat = format; }
/**
- * Set the time for this video to stop at. At this time in the video,
+ * Set the time for this video to end at. At this time in the video,
* all audio will stop and endOfVideo() will return true.
*/